@@ -17,7 +17,7 @@
 define various constant values used throughout the system.
 
 The majority of these properties are used to access certain values from the
-object dictionaries sent between the iPhone and Guzzoni server.
+object dictionaries sent between the iPhone and Apple's server.
 
 '''
 from pyamp.patterns import Enum
@@ -48,9 +48,9 @@ class Directions:
 
     '''
 
-    From_Guzzoni = "From_Guzzoni"
-    '''The From_Guzzoni property indicates that data was received from the
-    Guzzoni server.
+    From_Server = "From_Server"
+    '''The From_Server property indicates that data was received from Apple's
+    server.
 
     '''
 
@@ -63,7 +63,7 @@ class Directions:
 
 class ClassNames(Enum):
     '''The ClassNames class contains properties which define the names of the
-    class names of objects sent between the iPhone and the Guzzoni server.
+    class names of objects sent between the iPhone and Apple's server.
 
     '''
     AnyObject = "AnyObject"
@@ -134,7 +134,7 @@ class ClassNames(Enum):
 
 class Keys:
     '''The Keys class defines various properties which contain strings which
-    are keys to the dictionary objects sent between the iPhone and the Guzzoni
+    are keys to the dictionary objects sent between the iPhone and Apple's
     server.
 
     '''
@@ -241,12 +241,18 @@ class Keys:
     Text = "text"
     '''The text key for an object.'''
 
+    Title = "title"
+    '''The title key for an object.'''
+
     Tokens = "tokens"
     '''The tokens key for an object.'''
 
     Utterance = "utterance"
     '''The utterance key for an object.'''
 
+    Version = "v"
+    '''The version key for an object.'''
+
 
 class DirectionTypes:
     '''The DirectionTypes class encapsulates the various modes of
